==> vtk-6.3.0-5-armv6h.pkg.tar.xz: vtk/vtkGeoInteractorStyle.java <==
// java wrapper for vtkGeoInteractorStyle object
//

package vtk;
import vtk.*;

public class vtkGeoInteractorStyle extends vtkInteractorStyleTrackballCamera
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void OnEnter_2();
  public void OnEnter()
    { OnEnter_2(); }

  private native void OnLeave_3();
  public void OnLeave()
    { OnLeave_3(); }

  private native void OnMouseMove_4();
  public void OnMouseMove()
    { OnMouseMove_4(); }

  private native void OnLeftButtonUp_5();
  public void OnLeftButtonUp()
    { OnLeftButtonUp_5(); }

  private native void OnMiddleButtonUp_6();
  public void OnMiddleButtonUp()
    { OnMiddleButtonUp_6(); }

  private native void OnRightButtonUp_7();
  public void OnRightButtonUp()
    { OnRightButtonUp_7(); }

  private native void OnLeftButtonDown_8();
  public void OnLeftButtonDown()
    { OnLeftButtonDown_8(); }

  private native void OnMiddleButtonDown_9();
  public void OnMiddleButtonDown()
    { OnMiddleButtonDown_9(); }

  private native void OnRightButtonDown_10();
  public void OnRightButtonDown()
    { OnRightButtonDown_10(); }

  private native void OnChar_11();
  public void OnChar()
    { OnChar_11(); }

  private native void RubberBandZoom_12();
  public void RubberBandZoom()
    { RubberBandZoom_12(); }

  private native void Pan_13();
  public void Pan()
    { Pan_13(); }

  private native void Dolly_14();
  public void Dolly()
    { Dolly_14(); }

  private native void RedrawRectangle_15();
  public void RedrawRectangle()
    { RedrawRectangle_15(); }

  private native void StartState_16(int id0);
  public void StartState(int id0)
    { StartState_16(id0); }

  private native long GetGeoCamera_17();
  public vtkGeoCamera GetGeoCamera() {
    long temp = GetGeoCamera_17();

    if (temp == 0) return null;
    return (vtkGeoCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
  }

  private native void ResetCamera_18();
  public void ResetCamera()
    { ResetCamera_18(); }

  private native void WidgetInteraction_19(vtkObject id0);
  public void WidgetInteraction(vtkObject id0)
    { WidgetInteraction_19(id0); }

  private native void SetInteractor_20(vtkRenderWindowInteractor id0);
  public void SetInteractor(vtkRenderWindowInteractor id0)
    { SetInteractor_20(id0); }

  private native int GetRayIntersection_21(double id0[],double id1[],double id2[]);
  public int GetRayIntersection(double id0[],double id1[],double id2[])
    { return GetRayIntersection_21(id0,id1,id2); }

  private native void SetCurrentRenderer_22(vtkRenderer id0);
  public void SetCurrentRenderer(vtkRenderer id0)
    { SetCurrentRenderer_22(id0); }

  private native boolean GetLockHeading_23();
  public boolean GetLockHeading()
    { return GetLockHeading_23(); }

  private native void SetLockHeading_24(boolean id0);
  public void SetLockHeading(boolean id0)
    { SetLockHeading_24(id0); }

  private native void LockHeadingOn_25();
  public void LockHeadingOn()
    { LockHeadingOn_25(); }

  private native void LockHeadingOff_26();
  public void LockHeadingOff()
    { LockHeadingOff_26(); }

  private native void ResetCameraClippingRange_27();
  public void ResetCameraClippingRange()
    { ResetCameraClippingRange_27(); }

  public vtkGeoInteractorStyle() { super(); }

  public vtkGeoInteractorStyle(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-14-armv6h.pkg.tar.xz: vtk/vtkGeoInteractorStyle.java <==
// java wrapper for vtkGeoInteractorStyle object
//

package vtk;
import vtk.*;

public class vtkGeoInteractorStyle extends vtkInteractorStyleTrackballCamera
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void OnEnter_2();
  public void OnEnter()
    { OnEnter_2(); }

  private native void OnLeave_3();
  public void OnLeave()
    { OnLeave_3(); }

  private native void OnMouseMove_4();
  public void OnMouseMove()
    { OnMouseMove_4(); }

  private native void OnLeftButtonUp_5();
  public void OnLeftButtonUp()
    { OnLeftButtonUp_5(); }

  private native void OnMiddleButtonUp_6();
  public void OnMiddleButtonUp()
    { OnMiddleButtonUp_6(); }

  private native void OnRightButtonUp_7();
  public void OnRightButtonUp()
    { OnRightButtonUp_7(); }

  private native void OnLeftButtonDown_8();
  public void OnLeftButtonDown()
    { OnLeftButtonDown_8(); }

  private native void OnMiddleButtonDown_9();
  public void OnMiddleButtonDown()
    { OnMiddleButtonDown_9(); }

  private native void OnRightButtonDown_10();
  public void OnRightButtonDown()
    { OnRightButtonDown_10(); }

  private native void OnChar_11();
  public void OnChar()
    { OnChar_11(); }

  private native void RubberBandZoom_12();
  public void RubberBandZoom()
    { RubberBandZoom_12(); }

  private native void Pan_13();
  public void Pan()
    { Pan_13(); }

  private native void Dolly_14();
  public void Dolly()
    { Dolly_14(); }

  private native void RedrawRectangle_15();
  public void RedrawRectangle()
    { RedrawRectangle_15(); }

  private native void StartState_16(int id0);
  public void StartState(int id0)
    { StartState_16(id0); }

  private native long GetGeoCamera_17();
  public vtkGeoCamera GetGeoCamera() {
    long temp = GetGeoCamera_17();

    if (temp == 0) return null;
    return (vtkGeoCamera)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void ResetCamera_18();
  public void ResetCamera()
    { ResetCamera_18(); }

  private native void WidgetInteraction_19(vtkObject id0);
  public void WidgetInteraction(vtkObject id0)
    { WidgetInteraction_19(id0); }

  private native void SetInteractor_20(vtkRenderWindowInteractor id0);
  public void SetInteractor(vtkRenderWindowInteractor id0)
    { SetInteractor_20(id0); }

  private native int GetRayIntersection_21(double id0[],double id1[],double id2[]);
  public int GetRayIntersection(double id0[],double id1[],double id2[])
    { return GetRayIntersection_21(id0,id1,id2); }

  private native void SetCurrentRenderer_22(vtkRenderer id0);
  public void SetCurrentRenderer(vtkRenderer id0)
    { SetCurrentRenderer_22(id0); }

  private native boolean GetLockHeading_23();
  public boolean GetLockHeading()
    { return GetLockHeading_23(); }

  private native void SetLockHeading_24(boolean id0);
  public void SetLockHeading(boolean id0)
    { SetLockHeading_24(id0); }

  private native void LockHeadingOn_25();
  public void LockHeadingOn()
    { LockHeadingOn_25(); }

  private native void LockHeadingOff_26();
  public void LockHeadingOff()
    { LockHeadingOff_26(); }

  private native void ResetCameraClippingRange_27();
  public void ResetCameraClippingRange()
    { ResetCameraClippingRange_27(); }

  public vtkGeoInteractorStyle() { super(); }

  public vtkGeoInteractorStyle(long id) { super(id); }
  public native long   VTKInit();

}
